Coverage for markupmirror.exceptions: 100%

# Coverage for markupmirror.exceptions : 100%

## 2 statements 2 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 | class MarkupError(Exception): """General execution error for markups.""" class InvalidMarkup(Exception): """Raised when a markup is not subclassing BaseMarkup."""